badwing.level package
=====================

Submodules
----------

badwing.level.level module
--------------------------

.. automodule:: badwing.level.level
   :members:
   :undoc-members:
   :show-inheritance:

badwing.level.sticker module
----------------------------

.. automodule:: badwing.level.sticker
   :members:
   :undoc-members:
   :show-inheritance:

badwing.level.tile module
-------------------------

.. automodule:: badwing.level.tile
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: badwing.level
   :members:
   :undoc-members:
   :show-inheritance:
